@@ -43,7 +43,8 @@ class FileConstructor():
             instance_list: list = None,
             frame_packet_map: dict = None,
             assume_new_instances_machine_made: bool = True,
-            convert_names_to_label_files: bool = True
+            convert_names_to_label_files: bool = True,
+            parent_file_id: int = None
     ):
         """
         Create a Project file from local path
@@ -75,9 +76,8 @@ class FileConstructor():
                 assume_new_instances_machine_made = assume_new_instances_machine_made,
                 convert_names_to_label_files = convert_names_to_label_files
             )
-
+        json_payload['parent_file_id'] = parent_file_id
         files['json'] = (None, json.dumps(json_payload), 'application/json')
-
         endpoint = "/api/walrus/v1/project/" + self.client.project_string_id \
                    + "/input/from_local"
 
@@ -106,7 +106,8 @@ class FileConstructor():
                                directory_id: int = None,
                                bucket_name: str = None,
                                file_name: str = None,
-                               blob_path: str = None):
+                               blob_path: str = None,
+                               parent_file_id: int = None):
         packet = {'media': {}}
         packet['media']['url'] = url
         packet['media']['type'] = media_type
@@ -115,6 +116,7 @@ class FileConstructor():
         packet['frame_packet_map'] = frame_packet_map
         packet['type'] = type
         packet['connection_id'] = connection_id
+        packet['parent_file_id'] = parent_file_id
         packet['directory_id'] = directory_id
         packet['original_filename'] = file_name
         packet['bucket_name'] = bucket_name
@@ -137,7 +139,8 @@ class FileConstructor():
                        media_type: str = 'image',
                        instance_list: list = None,
                        file_name: str = None,
-                       frame_packet_map: dict = None):
+                       frame_packet_map: dict = None,
+                       parent_file_id: int = None):
         """
           Bind a blob path in the given connection ID into Diffgram
         :param blob_path:
@@ -163,7 +166,8 @@ class FileConstructor():
             connection_id = connection_id,
             file_name = name,
             directory_id = directory_id,
-            type = "from_blob_path"
+            type = "from_blob_path",
+            parent_file_id=parent_file_id
         )
         self.from_packet(packet = packet)
         return True
@@ -176,7 +180,8 @@ class FileConstructor():
             job_id: int = None,
             video_split_duration: int = None,
             instance_list: list = None,  # for Images
-            frame_packet_map: dict = None  # for Video
+            frame_packet_map: dict = None,  # for Video
+            parent_file_id: int = None
     ):
         """
 
@@ -208,7 +213,8 @@ class FileConstructor():
             job_id = job_id,
             video_split_duration = video_split_duration,
             instance_list = instance_list,
-            frame_packet_map = frame_packet_map
+            frame_packet_map = frame_packet_map,
+            parent_file_id = parent_file_id
         )
         self.from_packet(packet = packet)
 
